# Changelog

### Legend

- ![Feature](https://img.shields.io/badge/-Feature-blueviolet?style=flat-square) : Something that you couldn’t do before.
- ![Enhancement](https://img.shields.io/badge/-Enhancement-purple?style=flat-square) : A miscellaneous minor improvement.
- ![Efficiency](https://img.shields.io/badge/-Efficiency-indigo?style=flat-square) : An existing feature now may not require as much computation or memory.
- ![Fix](https://img.shields.io/badge/-Fix-red?style=flat-square) : Something that previously didn’t work as documented or as expected should now work.
- ![Documentation](https://img.shields.io/badge/-Documentation-blue?style=flat-square) : An update to the documentation.
- ![Other](https://img.shields.io/badge/-Other-lightgrey?style=flat-square) : Miscellaneous updates such as package structure or GitHub quality of life updates.

### Version 0.1.0

- ![Feature](https://img.shields.io/badge/-Feature-blueviolet?style=flat-square) : ['MetaNetwork'](https://github.com/paradoxysm/metanetwork/blob/master/metanetwork/_metanetwork.py) implemented!
